@@ -348,8 +348,8 @@ gpointer g_type_instance_get_private    (GTypeInstance              *instance,
  *                                                 gtk_tree_store_tree_model_init));
  */
 #define G_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init)       { \
-  static const GInterfaceInfo g_implement_interface_info = { \
-    (GInterfaceInitFunc) iface_init \
+  const GInterfaceInfo g_implement_interface_info = { \
+    (GInterfaceInitFunc) iface_init, NULL, NULL \
   }; \
   g_type_add_interface_static (g_define_type_id, TYPE_IFACE, &g_implement_interface_info); \
 }
@@ -412,21 +412,21 @@ GTypeValueTable* g_type_value_table_peek        (GType		     type);
 
 
 /*< private >*/
-gboolean	 g_type_check_instance          (GTypeInstance      *instance);
+gboolean	 g_type_check_instance          (GTypeInstance      *instance) G_GNUC_PURE;
 GTypeInstance*   g_type_check_instance_cast     (GTypeInstance      *instance,
 						 GType               iface_type);
 gboolean         g_type_check_instance_is_a	(GTypeInstance      *instance,
-						 GType               iface_type);
+						 GType               iface_type) G_GNUC_PURE;
 GTypeClass*      g_type_check_class_cast        (GTypeClass         *g_class,
 						 GType               is_a_type);
 gboolean         g_type_check_class_is_a        (GTypeClass         *g_class,
-						 GType               is_a_type);
-gboolean	 g_type_check_is_value_type     (GType		     type);
-gboolean	 g_type_check_value             (GValue		    *value);
+						 GType               is_a_type) G_GNUC_PURE;
+gboolean	 g_type_check_is_value_type     (GType		     type) G_GNUC_CONST;
+gboolean	 g_type_check_value             (GValue		    *value) G_GNUC_PURE;
 gboolean	 g_type_check_value_holds	(GValue		    *value,
-						 GType		     type);
+						 GType		     type) G_GNUC_PURE;
 gboolean         g_type_test_flags              (GType               type,
-						 guint               flags);
+						 guint               flags) G_GNUC_CONST;
 
 
 /* --- debugging functions --- */
@@ -435,15 +435,15 @@ G_CONST_RETURN gchar* g_type_name_from_class	(GTypeClass	*g_class);
 
 
 /* --- internal functions --- */
-void    g_value_c_init          (void) G_GNUC_INTERNAL; /* sync with gvalue.c */
-void    g_value_types_init      (void) G_GNUC_INTERNAL; /* sync with gvaluetypes.c */
-void    g_enum_types_init       (void) G_GNUC_INTERNAL; /* sync with genums.c */
-void    g_param_type_init       (void) G_GNUC_INTERNAL; /* sync with gparam.c */
-void    g_boxed_type_init       (void) G_GNUC_INTERNAL; /* sync with gboxed.c */
-void    g_object_type_init      (void) G_GNUC_INTERNAL; /* sync with gobject.c */
-void    g_param_spec_types_init (void) G_GNUC_INTERNAL; /* sync with gparamspecs.c */
-void    g_value_transforms_init (void) G_GNUC_INTERNAL; /* sync with gvaluetransform.c */
-void    g_signal_init           (void) G_GNUC_INTERNAL; /* sync with gsignal.c */
+G_GNUC_INTERNAL void    g_value_c_init          (void); /* sync with gvalue.c */
+G_GNUC_INTERNAL void    g_value_types_init      (void); /* sync with gvaluetypes.c */
+G_GNUC_INTERNAL void    g_enum_types_init       (void); /* sync with genums.c */
+G_GNUC_INTERNAL void    g_param_type_init       (void); /* sync with gparam.c */
+G_GNUC_INTERNAL void    g_boxed_type_init       (void); /* sync with gboxed.c */
+G_GNUC_INTERNAL void    g_object_type_init      (void); /* sync with gobject.c */
+G_GNUC_INTERNAL void    g_param_spec_types_init (void); /* sync with gparamspecs.c */
+G_GNUC_INTERNAL void    g_value_transforms_init (void); /* sync with gvaluetransform.c */
+G_GNUC_INTERNAL void    g_signal_init           (void); /* sync with gsignal.c */
 
 
 /* --- implementation bits --- */
